@@ -22,23 +22,19 @@ from PyQt5.QtTest import QTest
 from PyQt5.QtCore import QTimer
 
 # local imports
-from indibase import qtIndiBase
+from indibase.qtIndiBase import Client
 
 
 class IndiClass:
     """
-    the class indiClass inherits all information and handling of indi devices
-    this class will be only referenced from other classes and not directly used
-
-        >>> indi = IndiClass(app=None, data=None)
     """
 
     __all__ = ['IndiClass']
-
     log = logging.getLogger(__name__)
 
     RETRY_DELAY = 1500
     NUMBER_RETRY = 5
+    UPDATE_RATE = 1000
 
     INDIGO = {
         # numbers
@@ -103,11 +99,21 @@ class IndiClass:
     }
 
     def __init__(self, app=None, data=None, threadPool=None):
-        super().__init__()
-
         self.app = app
         self.data = data
-        self.client = qtIndiBase.Client(host=None, threadPool=threadPool)
+        self.client = Client(host=None, threadPool=threadPool)
+
+        if self.app is not None:
+            # this is for direct use of indiClass in devicePopupW for
+            # device discovery as we have in this case no app link, but we
+            # need the signaling work.
+            clientSig = self.client.signals
+            selfSig = self.signals
+            clientSig.deviceConnected.connect(selfSig.deviceConnected)
+            clientSig.deviceDisconnected.connect(selfSig.deviceDisconnected)
+            clientSig.serverConnected.connect(selfSig.serverConnected)
+            clientSig.serverDisconnected.connect(selfSig.serverDisconnected)
+
         self.deviceName = ''
         self.device = None
         self.deviceConnected = False
