@@ -18,12 +18,35 @@
 import logging
 import datetime
 from dateutil.tz import tzutc
-
+import sys
 # external packages
 
 # local imports
 
 
+class LoggerWriter:
+    # taken from:
+    # https://stackoverflow.com/questions/19425736/
+    # how-to-redirect-stdout-and-stderr-to-logger-in-python
+    def __init__(self, level, mode, std):
+        self.level = level
+        self.mode = mode
+        self.standard = std
+
+    def write(self, message):
+        self.standard.write(message)
+        first = True
+        for line in message.rstrip().splitlines():
+            if first:
+                self.level(f'[{self.mode}] ' + line.strip())
+                first = False
+            else:
+                self.level(' ' * 9 + line.strip())
+
+    def flush(self):
+        pass
+
+
 def timeTz(*args):
     return datetime.datetime.now(tzutc()).timetuple()
 
@@ -112,6 +135,9 @@ def setupLogging():
     addLoggingLevel('HEADER', 55)
     addLoggingLevel('UI', 35)
     addLoggingLevel('TRACE', 5)
+    # transfer all sys outputs to logging
+    sys.stderr = LoggerWriter(logging.getLogger().error, 'STDERR', sys.stderr)
+    sys.stdout = LoggerWriter(logging.getLogger().info, 'STDOUT', sys.stdout)
     return True
 
 
