@@ -36,7 +36,7 @@ class SatelliteWindowSignals(QObject):
     """
     """
     __all__ = ['SatelliteWindowSignals']
-    show = pyqtSignal(object, object, object, object, object)
+    show = pyqtSignal(object, object, object, object)
     update = pyqtSignal(object, object)
 
 
@@ -68,14 +68,12 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         self.satHorizonMat = self.embedMatplot(self.ui.satHorizon)
         self.satEarthMat = self.embedMatplot(self.ui.satEarth)
 
-        self.colors = [self.M_RED_L, self.M_YELLOW_L, self.M_GREEN_L]
-
+        self.colors = [self.M_RED1, self.M_YELLOW1, self.M_GREEN1]
         stream = QFile(':/data/worldmap.dat')
         stream.open(QFile.ReadOnly)
         pickleData = stream.readAll()
         stream.close()
         self.world = pickle.load(BytesIO(pickleData))
-
         self.signals.show.connect(self.drawSatellite)
         self.signals.update.connect(self.updatePositions)
 
@@ -109,8 +107,8 @@ class SatelliteWindow(toolsQtWidget.MWidget):
             self.app.config['satelliteW'] = {}
 
         config = self.app.config['satelliteW']
-        config['winPosX'] = self.pos().x()
-        config['winPosY'] = self.pos().y()
+        config['winPosX'] = max(self.pos().x(), 0)
+        config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
         config['width'] = self.width()
         config['tabWidget'] = self.ui.tabWidget.currentIndex()
@@ -124,6 +122,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         self.closing = True
         self.storeConfig()
         self.app.mount.signals.pointDone.disconnect(self.updatePointerAltAz)
+        self.app.colorChange.disconnect(self.colorChange)
         super().closeEvent(closeEvent)
 
     def showWindow(self):
@@ -131,10 +130,20 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         :return: True for test purpose
         """
         self.app.mount.signals.pointDone.connect(self.updatePointerAltAz)
+        self.app.colorChange.connect(self.colorChange)
         self.app.sendSatelliteData.emit()
         self.show()
         return True
 
+    def colorChange(self):
+        """
+        :return:
+        """
+        self.setStyleSheet(self.mw4Style)
+        self.colors = [self.M_RED1, self.M_YELLOW1, self.M_GREEN1]
+        self.drawSatellite()
+        return True
+
     @staticmethod
     def markerSatellite():
         """
@@ -345,7 +354,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
                                            markersize=35,
                                            linewidth=2,
                                            fillstyle='none',
-                                           color=self.M_WHITE_H)
+                                           color=self.M_WHITE)
         self.makeCubeLimits(axe)
         axe.figure.canvas.draw()
         return True
@@ -429,7 +438,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         lat = self.app.mount.obsSite.location.latitude.radians
         lon = self.app.mount.obsSite.location.longitude.radians
         x, y, z = functions.from_spherical(self.EARTH_RADIUS, lat, lon)
-        axe.plot(x, y, z, marker='.', markersize=12, color=self.M_YELLOW_H)
+        axe.plot(x, y, z, marker='.', markersize=12, color=self.M_YELLOW)
 
         if observe is None:
             axe.figure.canvas.draw()
@@ -446,7 +455,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
                                            markersize=35,
                                            linewidth=2,
                                            fillstyle='none',
-                                           color=self.M_WHITE_H)
+                                           color=self.M_WHITE)
         self.makeCubeLimits(axe)
         axe.figure.canvas.draw()
         return True
@@ -484,6 +493,9 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         """
         axe, fig = self.generateFlat(widget=self.satEarthMat)
         axe.set_xticks(np.arange(-180, 181, 45))
+        axe.set_xticklabels(['180 W', '135 W', '90 W', '45 W', '0',
+                             '45 E', '90 E', '135 E', '180 E'],
+                            rotation=30)
         axe.set_xlabel('Longitude in degrees')
         axe.set_ylabel('Latitude in degrees')
         axe.set_ylim([-90, 90])
@@ -500,7 +512,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
 
         lat = obsSite.location.latitude.degrees
         lon = obsSite.location.longitude.degrees
-        axe.plot(lon, lat, marker='.', markersize=5, color=self.M_YELLOW_H)
+        axe.plot(lon, lat, marker='.', markersize=5, color=self.M_YELLOW)
 
         ts = obsSite.ts
         subpoint = wgs84.subpoint(self.satellite.at(ts.now()))
@@ -509,7 +521,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         self.plotSatPosEarth, = axe.plot(lon, lat,
                                          marker=self.markerSatellite(),
                                          markersize=35, lw=2, fillstyle='none',
-                                         ls='none', color=self.M_WHITE_H,
+                                         ls='none', color=self.M_WHITE,
                                          clip_on=False,
                                          zorder=10)
 
@@ -550,7 +562,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         lat = subpoints.latitude.degrees
         lon = subpoints.longitude.degrees
         for slc in self.unlinkWrap(lon):
-            axe.plot(lon[slc], lat[slc], lw=1, color=self.M_WHITE_L, zorder=-10)
+            axe.plot(lon[slc], lat[slc], lw=1, color=self.M_WHITE1, zorder=-10)
         axe.figure.canvas.draw()
         return True
 
@@ -568,7 +580,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         altF = np.concatenate([[0], [alt[0]], alt, [alt[-1]], [0]])
         azF = np.concatenate([[0], [0], az, [360], [360]])
 
-        axes.fill(azF, altF, color=self.M_GREY_LL, alpha=0.5, zorder=-10)
+        axes.fill(azF, altF, color=self.M_GREY1, alpha=0.5, zorder=-10)
         axes.plot(az, alt, color=self.M_BLUE, marker='', alpha=0.7, lw=2)
         return True
 
@@ -649,12 +661,12 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         self.plotSatPosHorizon, = axe.plot(az.degrees, alt.degrees,
                                            marker=self.markerSatellite(),
                                            markersize=35, lw=2, fillstyle='none',
-                                           ls='none', color=self.M_WHITE_H,
+                                           ls='none', color=self.M_WHITE,
                                            zorder=10)
 
         self.pointerAltAz, = axe.plot(np.radians(180), 45,
                                       zorder=-5,
-                                      color=self.M_PINK_H,
+                                      color=self.M_PINK,
                                       marker=self.markerAltAz(),
                                       markersize=20,
                                       linestyle='none',
@@ -666,7 +678,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         return True
 
     def drawSatellite(self, satellite=None, satOrbits=None, altitude=[],
-                      azimuth=[], isSunlit=[]):
+                      azimuth=[]):
         """
         drawSatellite draws 4 different views of the actual satellite
         situation: two sphere views, a horizon view and an earth view.
@@ -677,7 +689,6 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         :param satOrbits:
         :param altitude:
         :param azimuth:
-        :param isSunlit:
         :return: True for test purpose
         """
         if self.closing:
@@ -707,8 +718,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
                        satOrbits=satOrbits, altitude=altitude, azimuth=azimuth)
         self.drawHorizonView(self.app.mount.obsSite,
                              satOrbits=satOrbits,
-                             altitude=altitude, azimuth=azimuth,
-                             isSunlit=isSunlit)
+                             altitude=altitude, azimuth=azimuth)
         self.drawSphere1(observe=observe)
         self.drawSphere2(observe=observe)
         return True
