@@ -276,6 +276,31 @@ def setupWorkDirs(mwGlob):
     return mwGlob
 
 
+def checkIsAdmin():
+    """
+    :return:
+    """
+    if platform.system() == 'Windows':
+        import ctypes
+        try:
+            state = ctypes.windll.shell32.IsUserAnAdmin() == 1
+        except Exception as e:
+            log.error(f'Check admin error: [{e}]')
+            state = None
+    else:
+        try:
+            state = os.getuid() == 0
+        except Exception as e:
+            log.error(f'Check admin error: [{e}]')
+            state = None
+    if state is None:
+        return 'unknown'
+    elif state:
+        return 'yes'
+    else:
+        return 'no'
+
+
 def writeSystemInfo(mwGlob=None):
     """
     writeSystemInfo print overview data to the log file at the beginning of
@@ -295,6 +320,7 @@ def writeSystemInfo(mwGlob=None):
     log.header(f'python runtime   : {platform.architecture()[0]}')
     log.header(f'PyQt5 / Qt       : {PYQT_VERSION_STR} / {QT_VERSION_STR}')
     log.header(f'node / hostname  : {platform.node()} / {socket.gethostname()}')
+    log.header(f'run as admin     : {checkIsAdmin()}')
     log.header('-' * 100)
 
     return True
@@ -346,7 +372,7 @@ def extractDataFiles(mwGlob=None, splashW=None):
             QFile.copy(f':/data/{file}', filePath)
             log.debug(f'Writing file:  [{file}]')
         else:
-            log.info(f'Using existing file: [{file}]')
+            log.info(f'Using existing: [{file}]')
 
         os.chmod(filePath, 0o666)
     return True
